dec384

Macro dec384 

macro_rules! dec384 {
    ($($body:tt)*) => { ... };
}
A macro to construct 384-bit signed D384 decimal from literals in compile time.

Const-evaluated in compile time macro-helper can be used for definitions of constants or variables whose value is known in compile time.

Examples:

Basic usage:

use fastnum::*;

const N: D384 = dec384!(1.23456789);
assert!(!N.is_zero());

let num = dec384!(0);
assert!(num.is_zero());

const A: D384 = dec384!(5);
const B: D384 = dec384!(1_000);
const C: D384 = A.div(B);

assert_eq!(C, dec384!(0.005));

Static assertions:

// The below example will fail to compile, as the function will panic at compile time:
use fastnum::{dec384, D384};

// Gives a compile error of "error[E0080]: evaluation of constant value failed...
// the evaluated program panicked at 'attempt to parse decimal from string containing invalid digit'",
const N: D384 = dec384!(A1.23456789);

This allows you to perform all the necessary checks such as potentialy overflow or calculation accuracy loss and others at the compile time. Protect from unexpected errors in runtime.